<?php
/*
 * WPstart functions and definitions.
 *
 * @package WordPress
 * @subpackage WPstart
 */

/* Background */
add_custom_background();

/* Content width */
if ( ! isset( $content_width ) )
	$content_width = 700;
	
/* Editor styling */
add_editor_style();

/* Feed links and comments RSS to head */
add_theme_support( 'automatic-feed-links' );
	
/* Header management */
define( 'HEADER_TEXTCOLOR', '000' );
define( 'HEADER_IMAGE', '%s/images/headers/header-image.jpg' );
define( 'HEADER_IMAGE_WIDTH', apply_filters( 'wpstart_header_image_width', 940 ) );
define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'wpstart_header_image_height', 300 ) );
add_custom_image_header('wpstart_header_style', 'wpstart_admin_header_style', 'wpstart_admin_header_image');

/* Header management: style for site-title and site-description */
if ( !function_exists( 'wpstart_header_style' ) ) :
function wpstart_header_style() {
	if ( HEADER_TEXTCOLOR == get_header_textcolor() )
		return; ?>
	<style type="text/css">
	<?php if ( 'blank' == get_header_textcolor() ) : ?>
		.site-title, .site-description { display:none!important; visibility:hidden!important; }
	<?php else : ?>
		.site-title a, .site-description { color:#<?php echo get_header_textcolor(); ?>!important; }
	<?php endif; ?>
	</style>
<?php } endif;

if ( !function_exists( 'wpstart_admin_header_style' ) ) :
	function wpstart_admin_header_style() { ?>
		<style type="text/css">
			.appearance_page_custom-header #headimg { border:none; }
			#headimg { font-family:Arial,sans-serif; width:<?php echo HEADER_IMAGE_WIDTH; ?>px; height:<?php echo HEADER_IMAGE_HEIGHT; ?>px; }
			#headimg a { text-decoration:none; }
			#headimg .header-left { display:inline; float:left; position:relative; margin-left:10px; margin-right:10px; padding:15px 0 0 0; width:220px; }
			#headimg h1.site-title { color:#000; font-size:30px; font-weight:bold; margin-bottom:0; }
			#headimg h1.site-title a { color:#000; font-size:30px; font-weight:bold; line-height:1; margin-bottom:0; }
			#headimg h1.site-title a:hover { color:#1155CC; }
			#headimg .site-description { font-size:12px; }			
			#headimg .header-image { border-top:10px solid #CCC; display:inline; float:left; position:relative; margin-left:10px; margin-right:10px; width:940px; }		
		</style>
	<?php } endif;

/* Header management: appearance page for custom header */	
if ( !function_exists( 'wpstart_admin_header_image' ) ) :
	function wpstart_admin_header_image() { ?>
		<div id="headimg">
			<div class="header-left">
				<h1 class="site-title">
					<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>
				</h1>
				<h2 class="site-description"><span><?php bloginfo('description'); ?></span></h2>
			</div>		
		
			<?php $header_image = get_header_image();
			if ( ! empty( $header_image ) ) : ?>
				<img src="<?php echo esc_url( $header_image ); ?>" width="<?php echo HEADER_IMAGE_WIDTH; ?>" height="<?php echo HEADER_IMAGE_HEIGHT; ?>" alt="" class="header-image" />
			<?php endif; ?>
		</div>
	<?php } endif;

/* Load content extensions */
require_once( get_template_directory() . '/includes/content-extensions.php');

/* Navigation menu */
register_nav_menus( array(
	'navigation' => __( 'Navigation Menu', 'wpstart' ),
) );

/* Navigation menu: add home link */
function wpstart_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'wpstart_page_menu_args' );

/* Post thumbnails */
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 150, 150, true ); // default post thumbnails: 150 pixels wide by 150 pixels tall, crop mode

/* "Read more" link */
function wpstart_read_more_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '" class="read-more"><span>' . __( 'More &raquo;', 'wpstart' ) . '</span></a>';
}

/* "Read more" link: replace "[...]" with "..." in automatically generated excerpts */
function wpstart_auto_excerpt_more( $more ) {
	return '&hellip;' . wpstart_read_more_link();
}
add_filter( 'excerpt_more', 'wpstart_auto_excerpt_more' );

/* "Read more" link: add "Read more" link to custom post excerpts. */
function wpstart_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= wpstart_read_more_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'wpstart_custom_excerpt_more' );

/* Translation */
load_theme_textdomain( 'wpstart', get_template_directory() . '/languages' );
$locale = get_locale();
$locale_file = get_template_directory() . "/languages/$locale.php";
if ( is_readable( $locale_file ) )
	require_once( $locale_file );

/* Widgetized areas */
function wpstart_widgets_init() {
	// Sidebar 1
	register_sidebar( array(
		'name' => __( 'Sidebar 1', 'wpstart' ),
		'id' => 'sidebar-1',
		'description' => __( 'Sidebar 1', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	// Sidebar 2
	register_sidebar( array(
		'name' => __( 'Sidebar 2', 'wpstart' ),
		'id' => 'sidebar-2',
		'description' => __( 'Sidebar 2', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	// Header
	register_sidebar( array(
		'name' => __( 'Header', 'wpstart' ),
		'id' => 'header',
		'description' => __( 'Header', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	// Footer 1
	register_sidebar( array(
		'name' => __( 'Footer 1', 'wpstart' ),
		'id' => 'footer-1',
		'description' => __( 'Footer 1', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Footer 2
	register_sidebar( array(
		'name' => __( 'Footer 2', 'wpstart' ),
		'id' => 'footer-2',
		'description' => __( 'Footer 2', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Footer 3
	register_sidebar( array(
		'name' => __( 'Footer 3', 'wpstart' ),
		'id' => 'footer-3',
		'description' => __( 'Footer 3', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	// Footer 4
	register_sidebar( array(
		'name' => __( 'Footer 4', 'wpstart' ),
		'id' => 'footer-4',
		'description' => __( 'Footer 4', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	// Colophon
	register_sidebar( array(
		'name' => __( 'Colophon', 'wpstart' ),
		'id' => 'colophon',
		'description' => __( 'Colophon', 'wpstart' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'wpstart_widgets_init' );


/**
 * WPstart actions.
 */

/* Head */
add_action( 'wpstart_head', 'wpstart_head', 10);

/* Before header */
add_action( 'wpstart_before_header', 'wpstart_noscript', 10);

/* Header */
add_action( 'wpstart_header', 'wpstart_header_content', 10);
add_action( 'wpstart_header', 'wpstart_header_image', 20);

/* After header */
add_action( 'wpstart_after_header', 'wpstart_nav', 10);

/* Before main */
// wpstart_before_main

/* Posts */
// wpstart_before_post_loop
add_action( 'wpstart_post_before_entry_content', 'wpstart_post_entry_meta', 10);
add_action( 'wpstart_post_entry_summary', 'wpstart_post_entry_summary', 10);
add_action( 'wpstart_post_after_entry_content', 'wpstart_post_entry_data', 10);
add_action( 'wpstart_post_no_results_not_found', 'wpstart_post_no_results_not_found', 10);
add_action( 'wpstart_after_post_loop', 'wpstart_post_pagination', 10);

/* Single */
// wpstart_before_single_post
add_action( 'wpstart_single_before_entry_content', 'wpstart_single_entry_meta', 10);
add_action( 'wpstart_single_entry_content', 'wpstart_single_entry_content', 10);
add_action( 'wpstart_single_after_entry_content', 'wpstart_single_entry_data', 10);
add_action( 'wpstart_after_single_post', 'wpstart_single_entry_navigation', 10);

/* Attachment */
add_action( 'wpstart_before_attachment_post', 'wpstart_attachment_navigation_above', 10);
add_action( 'wpstart_attachment_before_entry_content', 'wpstart_attachment_entry_meta', 10);
add_action( 'wpstart_attachment_entry_content', 'wpstart_attachment_entry_content', 10);
add_action( 'wpstart_attachment_after_entry_content', 'wpstart_attachment_entry_data', 10);
add_action( 'wpstart_after_attachment_post', 'wpstart_attachment_navigation_below', 10);

/* After main */
// wpstart_after_main

/* Footer */
add_action( 'wpstart_footer', 'wpstart_footer_content', 10);

/* General */
add_action( 'wpstart_entry_title', 'wpstart_entry_title', 10);
add_action( 'wpstart_page_title', 'wpstart_page_title', 10);
add_action( 'wpstart_search_form', 'wpstart_search_form', 10);
add_action( 'wpstart_search_no_results_not_found', 'wpstart_search_no_results_not_found', 10);


?>