<?php

/* wpstart_attachment_entry_content */
if ( !function_exists( 'wpstart_attachment_entry_content' ) ) {
	function wpstart_attachment_entry_content() {
		?>		
		<div class="entry-content">
			<div class="entry-attachment">
			<?php if ( wp_attachment_is_image() ) : ?>
			<img class="aligncenter" src="<?php echo wp_get_attachment_url(); ?>" alt="<?php the_title_attribute(); ?>" title="<?php the_title_attribute(); ?>" />
			<?php else : // attachment is not an image ?>
			<a href="<?php echo wp_get_attachment_url(); ?>" title="<?php echo esc_attr( get_the_title() ); ?>" rel="attachment"><?php echo basename( get_permalink() ); ?></a>
			<?php endif; ?>
			</div>
		</div>
		<?php
	}
}

/* wpstart_attachment_entry_data */
if ( !function_exists( 'wpstart_attachment_entry_data' ) ) {
	function wpstart_attachment_entry_data() { 
	?>
		<div class="entry-data">
			<?php if ( count( get_the_category() ) ) : ?>					
				<span class="cat-links">
					<?php printf('<span class="%1$s">' . __( 'Categories', 'wpstart' ) . ':</span> %2$s', 'data-category-prep', get_the_category_list( ', ' ) ); ?>
				</span>
			<?php endif; ?>
							
			<?php
				$tags = get_the_tag_list( '', ', ' );
				if ( $tags ):
			?>
				<span class="data-tags">
					<?php printf( '<span class="%1$s">%2$s</span> %3$s', 'data-tags-prep', __( 'Tags:', 'wpstart' ), $tags ); ?>
				</span>
			<?php endif; ?>
							
			<span class="data-bookmark"><?php _e( 'Bookmark', 'wpstart' ); ?> <a href="<?php echo get_permalink() ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></span>
							
			<?php
			if ( wp_attachment_is_image() ) {
				$metadata = wp_get_attachment_metadata();
				printf( __( 'Original dimensions %s', 'wpstart' ),
					sprintf( '<a href="%1$s" title="%2$s">%3$s &times; %4$s</a>',
						wp_get_attachment_url(),
						esc_attr( __( 'Link to image', 'wpstart' ) ),
						$metadata['width'],
						$metadata['height']
					)
				);
			}
			?>
							
			<?php edit_post_link( __( 'Edit', 'wpstart' ), '<span class="edit-link">', '</span>' ); ?>
		</div>	
	<?php 
	}
}

/* wpstart_attachment_entry_meta */
if ( !function_exists( 'wpstart_attachment_entry_meta' ) ) {
	function wpstart_attachment_entry_meta() {
		echo '<div class="entry-meta">';
				printf('<span class="meta-date-prep">' . __( 'Published on:', 'wpstart' ) . '</span> %1$s',
					sprintf( '<span class="meta-date">%1$s</span> ',
						get_the_date()
					)
				);
				
				printf('<span class="meta-author-prep">' . __( 'Author:', 'wpstart' ) . '</span> %1$s',
					sprintf( '<span class="meta-author-link"><a href="%1$s" title="%2$s">%3$s</a></span>',
						get_author_posts_url( get_the_author_meta( 'ID' ) ),
						sprintf( esc_attr__( 'View posts by this author', 'wpstart' ), get_the_author() ),
						get_the_author()
					)
				);
				
			if ( comments_open() && ! post_password_required() ) :
				echo '<span class="meta-comments-link">';
					comments_popup_link( __( 'Leave a comment', 'wpstart' ), __( '1 Comment', 'wpstart' ), __( '% Comments', 'wpstart' ), 'comments-link' );
				echo '</span>';
			endif;	
		echo '</div>';
	}
}

/* wpstart_attachment_navigation_above */
if ( !function_exists( 'wpstart_attachment_navigation_above' ) ) {
	function wpstart_attachment_navigation_above() {
		?>
		<span class="back-to-entry"><a href="<?php echo get_permalink( $post->post_parent ); ?>" title="<?php esc_attr( get_the_title( $post->post_parent ) ); ?>">
		<?php printf( __( '&larr; Back to %s', 'wpstart' ), get_the_title( $post->post_parent ) ); ?></a></span>
		
		<div class="attachment-navigation-above">
			<div class="previous-attachment"><?php previous_image_link( false ) ?></div>
			<div class="next-attachment"><?php next_image_link( false ) ?></div>
		</div>
		<?php
	}
}

/* wpstart_attachment_navigation_below */
if ( !function_exists( 'wpstart_attachment_navigation_below' ) ) {
	function wpstart_attachment_navigation_below() { 
		?>
		<div class="attachment-navigation-below">
			<div class="previous-attachment"><?php previous_image_link( false ) ?></div>
			<div class="next-attachment"><?php next_image_link( false ) ?></div>
		</div>
		<?php
	}
}	

/* wpstart_body_class */
if ( !function_exists( 'wpstart_body_class' ) ) {
	function wpstart_body_class($classes) {
		$classes[] = 'template-2columns-right';	
		return $classes;
	}
}
add_filter('body_class', 'wpstart_body_class');

/* wpstart_entry_title */
if ( !function_exists( 'wpstart_entry_title' ) ) {
	function wpstart_entry_title() {	
		if ( is_single() || is_page() ) { ?>
			<h1 class="entry-title"><?php the_title(); ?></h1>
		<?php } elseif (is_404()) { ?>
			<h1 class="entry-title"><?php _e( 'Page not found', 'wpstart' ); ?> - 404</h1>
		<?php } else { ?>
			<h2 class="entry-title"><a href="<?php the_permalink(); ?>" title="<?php the_title_attribute( array('before' => esc_attr__( 'Permalink: ', 'wpstart' ), 'after' => '')); ?>" rel="bookmark"><?php the_title(); ?></a></h2>
		<?php }
	}
}

/* wpstart_footer_content */
if ( !function_exists( 'wpstart_footer_content' ) ) {
	function wpstart_footer_content() { 
	?>
		<?php get_sidebar('footer'); ?>
			
		<div id="colophon">
		<?php if ( is_active_sidebar( 'colophon' ) ) : ?>
			<ul class="widget-area first">
				<?php dynamic_sidebar( 'colophon' ); ?>
			</ul>
		<?php else: ?>	
			<ul class="widget-area first">
				<li id="text" class="widget-container widget_text">		
					<div class="textwidget">
						<p>&copy; <a href="<?php echo home_url( '/' ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" class="site-info" rel="home"><?php bloginfo( 'name' ); ?></a>. <a href="http://wordpress.org" title="<?php echo esc_attr( _e( 'Powered by WordPress', 'wpstart' ) ); ?>" class="site-generator" rel="generator"><?php echo esc_attr( _e( 'Powered by WordPress', 'wpstart' ) ); ?></a> &amp; <a href="http://krusze.pl/wpstart" title="WPstart Theme" class="site-webdesign" rel="designer" target="_blank">WPstart Theme</a>.</p>	
					</div>
				</li>
			</ul>
		<?php endif; ?>
		</div>		
	<?php
	}
}

/* wpstart_head */
if ( !function_exists( 'wpstart_head' ) ) {
	function wpstart_head() { 
	?>
<head profile="http://gmpg.org/xfn/11">
<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />

<title><?php wp_title('', true); ?></title>

<link rel="stylesheet" type="text/css" media="all" href="<?php bloginfo( 'stylesheet_url' ); ?>" />
<link rel="pingback" href="<?php bloginfo('pingback_url'); ?>" />

<!-- WPstart v1.0.5 - http://krusze.pl -->

<?php if ( is_singular() && get_option( 'thread_comments' ) ) wp_enqueue_script( 'comment-reply' ); ?>

<?php wp_head(); ?>
</head>
	<?php
	}
}

/* wpstart_header_content */
if ( !function_exists( 'wpstart_header_content' ) ) {
	function wpstart_header_content() { 
	?>
		<div class="header-left">
			<?php $logo_tag = ( is_home() || is_front_page() ) ? 'h1' : 'div'; ?>
			<<?php echo $logo_tag; ?> class="site-title">
				<a href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a>
			</<?php echo $logo_tag; ?>>
			<h2 class="site-description"><span><?php bloginfo('description'); ?></span></h2>
		</div>
			
		<?php if ( is_active_sidebar( 'header' ) ) : ?>
		<div class="sidebar header-right">
			<ul class="widget-area first">
				<?php dynamic_sidebar( 'header' ); ?>
			</ul>
		</div>
		<?php endif; ?>
	<?php
	}
}

/* wpstart_header_image */
if ( !function_exists( 'wpstart_header_image' ) ) {
	function wpstart_header_image() {
		$header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php header_image(); ?>" width="<?php echo HEADER_IMAGE_WIDTH; ?>" height="<?php echo HEADER_IMAGE_HEIGHT; ?>" alt="" class="header-image" />
		<?php endif;
	}
}

/* wpstart_nav */
if ( !function_exists( 'wpstart_nav' ) ) {
	function wpstart_nav() {
		?> 
		<div id="nav-wrap">
			<div id="nav">
				<div class="screen-reader-text">
					<a href="#content" title="<?php esc_attr_e( 'Content', 'wpstart' ); ?>"><?php _e( 'Content', 'wpstart' ); ?></a>
				</div>	
				<?php wp_nav_menu( array( 'container_class' => 'menu', 'theme_location' => 'navigation' ) ); ?>
			</div>
		</div>
		<?php
	}
}

/* wpstart_noscript */
if ( !function_exists( 'wpstart_noscript' ) ) {
	function wpstart_noscript() {
		?>
		<noscript>
			<div class="noscript-wrap">
				<div class="noscript">
					<p><strong><?php _e( 'Enable JavaScript', 'wpstart' ); ?></strong></p>
				</div>
			</div>
		</noscript>
		<?php
	}
}

/* wpstart_page_title */
if ( !function_exists( 'wpstart_page_title' ) ) {
	function wpstart_page_title() {	
		if (is_author()) { ?>
			<h1 class="page-title"><?php printf( __('Posts by %s', 'wpstart'), '<span class="vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) ) . '" title="' . esc_attr( get_the_author() ) . '" rel="me">' . get_the_author() . '</a></span>' ); ?></h1>
		<?php } elseif (is_category()) { ?>
			<h1 class="page-title"><?php printf( __( 'You are currently browsing the archives for the %s category.', 'wpstart' ), '<span>' . single_cat_title( '', false ) . '</span>' ); ?></h1>
			<?php
				$category_description = category_description();
				if ( ! empty( $category_description ) ) : ?>
					<div class="category-description"><?php echo category_description(); ?></div>
			<?php endif; ?>			
		<?php } elseif (is_search()) { ?>
			<h1 class="page-title"><?php printf( __( 'Search results for &#8220;%s&#8221;', 'wpstart' ), '<span>' . get_search_query() . '</span>' ); ?></h1>
		<?php } elseif (is_tag()) { ?>
			<h1 class="page-title"><?php printf( __( 'Tag Archives: %s', 'wpstart' ), '<span>' . single_tag_title( '', false ) . '</span>' ); ?></h1>
		<?php } elseif (is_day()) { ?>
			<h1 class="page-title"><?php printf( __( 'Daily Archives: <span>%s</span>', 'wpstart' ), get_the_date() ); ?></h1>
		<?php } elseif (is_month()) { ?>
			<h1 class="page-title"><?php printf( __( 'Monthly Archives: <span>%s</span>', 'wpstart' ), get_the_date( 'F Y' ) ); ?></h1>
		<?php } elseif (is_year()) { ?>
			<h1 class="page-title"><?php printf( __( 'Yearly Archives: <span>%s</span>', 'wpstart' ), get_the_date( 'Y' ) ); ?></h1>
		<?php } elseif (isset($_GET['paged']) && !empty($_GET['paged'])) { ?>
			<h1 class="page-title"><?php _e( 'Archives', 'wpstart' ); ?></h1>';
		<?php }
	}
}

/* wpstart_post_entry_data */
if ( !function_exists( 'wpstart_post_entry_data' ) ) {
	function wpstart_post_entry_data() {
		echo '<div class="entry-data">';
			if ( count( get_the_category() ) ) :			
				echo '<span class="cat-links">';
					printf('<span class="%1$s">' . __( 'Categories', 'wpstart' ) . ':</span> %2$s', 'data-category-prep', get_the_category_list( ', ' ) );
				echo '</span>';
			endif;
							
			$tags = get_the_tag_list( '', ', ' );
			if ( $tags ):
				echo '<span class="data-tags">';
					printf( '<span class="%1$s">%2$s</span> %3$s', 'data-tags-prep', __( 'Tags:', 'wpstart' ), $tags );
				echo '</span>';
			endif;
			
			echo '<span class="data-bookmark-prep">';
			printf('<a %1$s class="data-bookmark">' . __( 'Bookmark', 'wpstart' ) . '</a> ',
				'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink: %s', 'wpstart' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"'
			);
			echo '</span>';

			edit_post_link( __( '(Edit)', 'wpstart' ), '<span class="edit-link">', '</span>' );
		echo '</div>';
	}
}

/* wpstart_post_entry_meta */
if ( !function_exists( 'wpstart_post_entry_meta' ) ) {
	function wpstart_post_entry_meta() {
		if ( 'post' == get_post_type() ) : 	
			echo '<div class="entry-meta">';
					printf('<span class="meta-date-prep">' . __( 'Published on:', 'wpstart' ) . '</span> %1$s',
						sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="meta-date">%3$s</span></a> ',
							get_permalink(),
							esc_attr( get_the_time() ),
							get_the_date()
						)
					);
					
					printf('<span class="meta-author-prep">' . __( 'Author:', 'wpstart' ) . '</span> %1$s',
						sprintf( '<span class="meta-author-link"><a href="%1$s" title="%2$s">%3$s</a></span>',
							get_author_posts_url( get_the_author_meta( 'ID' ) ),
							sprintf( esc_attr__( 'View posts by this author', 'wpstart' ), get_the_author() ),
							get_the_author()
						)
					);
					
				if ( comments_open() && ! post_password_required() ) :
					echo '<span class="meta-comments-link">';
						comments_popup_link( __( 'Leave a comment', 'wpstart' ), __( '1 Comment', 'wpstart' ), __( '% Comments', 'wpstart' ), 'comments-link' );
					echo '</span>';
				endif;	
			echo '</div>';
		endif;
	}
}

/* wpstart_post_entry_summary */
if ( !function_exists( 'wpstart_post_entry_summary' ) ) {
	function wpstart_post_entry_summary() {
		?>
		<div class="entry-summary">
			<?php if (has_post_thumbnail()){ ?>
			<a href="<?php the_permalink() ?>" title="<?php the_title_attribute( array('before' => esc_attr__( 'Permalink: ', 'wpstart' ), 'after' => '')); ?>" rel="bookmark"><?php the_post_thumbnail(); ?></a>
			<?php } ?>
			<?php the_excerpt(); ?>
		</div>
		<?php
	}
}

/* wpstart_post_no_results_not_found */
if ( !function_exists( 'wpstart_post_no_results_not_found' ) ) {
	function wpstart_post_no_results_not_found() {
		?>
		<div id="post-0" class="post no-results not-found">
			<h1 class="entry-title"><?php _e( 'No posts found.', 'wpstart' ); ?></h1>
			<div class="entry-content">
				<?php get_search_form(); ?>
			</div>
		</div>
		<?php
	}
}

/* wpstart_post_pagination */
if ( !function_exists( 'wpstart_post_pagination' ) ) {
	function wpstart_post_pagination() {
		global $wp_query;
		if (  $wp_query->max_num_pages > 1 ) : ?>
		<div class="navigation">
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older', 'wpstart' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer <span class="meta-nav">&rarr;</span>', 'wpstart' ) ); ?></div>
		</div>
		<?php endif;
	}
}

/* wpstart_search_form */
if ( !function_exists( 'wpstart_search_form' ) ) {
	function wpstart_search_form() {
		?>		
		<form method="get" id="searchform" action="<?php echo esc_url( home_url( '/' ) ); ?>">
			<div>
				<label class="screen-reader-text" for="s"><?php _e( 'Search', 'wpstart' ) ?></label>
				<input type="text" value="<?php esc_attr_e( 'Search for:', 'wpstart' ) ?>" name="s" id="s" onfocus="if (this.value == '<?php esc_attr_e( 'Search for:', 'wpstart' ) ?>') {this.value = '';}" onblur="if (this.value == '') {this.value = '<?php esc_attr_e( 'Search for:', 'wpstart' ) ?>';}" />
				<input type="submit" id="searchsubmit" value="<?php esc_attr_e( 'Search', 'wpstart' ) ?>" />
			</div>
		</form>
		<?php
	}
}

/* wpstart_search_no_results_not_found */
if ( !function_exists( 'wpstart_search_no_results_not_found' ) ) {
	function wpstart_search_no_results_not_found() {
		?>		
		<div id="post-0" class="post no-results not-found">
			<h1 class="entry-title"><?php _e( 'No results found.', 'wpstart' ); ?></h1>
			<div class="entry-content">
				<p><?php _e( 'Sorry, no posts matched your criteria.', 'wpstart' ); ?></p>
				<?php get_search_form(); ?>
			</div>
		</div>
		<?php
	}
}

/* wpstart_single_entry_content */
if ( !function_exists( 'wpstart_single_entry_content' ) ) {
	function wpstart_single_entry_content() {
		?>		
		<div class="entry-content">
			<?php if ( has_post_thumbnail()) { $large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large');
			echo '<a href="' . $large_image_url[0] . '" title="' . the_title_attribute('echo=0') . '" >';
			the_post_thumbnail();
			echo '</a>';
			} ?>
			<?php the_content(); ?>				
			<?php wp_link_pages( array( 'before' => '<div class="link-pages">' . __('Pages:', 'wpstart'), 'after' => '</div>' ) ); ?>
		</div>
		<?php
	}
}

/* wpstart_single_entry_data */
if ( !function_exists( 'wpstart_single_entry_data' ) ) {
	function wpstart_single_entry_data() {
		echo '<div class="entry-data">';
			if ( count( get_the_category() ) ) :			
				echo '<span class="cat-links">';
					printf('<span class="%1$s">' . __( 'Categories', 'wpstart' ) . ':</span> %2$s', 'data-category-prep', get_the_category_list( ', ' ) );
				echo '</span>';
			endif;
							
			$tags = get_the_tag_list( '', ', ' );
			if ( $tags ):
				echo '<span class="data-tags">';
					printf( '<span class="%1$s">%2$s</span> %3$s', 'data-tags-prep', __( 'Tags:', 'wpstart' ), $tags );
				echo '</span>';
			endif;
			
			echo '<span class="data-bookmark-prep">';
			printf('<a %1$s class="data-bookmark">' . __( 'Bookmark', 'wpstart' ) . '</a> ',
				'href="' . get_permalink() . '" title="' . sprintf( esc_attr__( 'Permalink: %s', 'wpstart' ), the_title_attribute( 'echo=0' ) ) . '" rel="bookmark"'
			);
			echo '</span>';

			edit_post_link( __( '(Edit)', 'wpstart' ), '<span class="edit-link">', '</span>' );
		echo '</div>';
	}
}

/* wpstart_single_entry_meta */
if ( !function_exists( 'wpstart_single_entry_meta' ) ) {
	function wpstart_single_entry_meta() {
		echo '<div class="entry-meta">';
				printf('<span class="meta-date-prep">' . __( 'Published on:', 'wpstart' ) . '</span> %1$s',
					sprintf( '<span class="meta-date">%1$s</span> ',
						get_the_date()
					)
				);
				
				printf('<span class="meta-author-prep">' . __( 'Author:', 'wpstart' ) . '</span> %1$s',
					sprintf( '<span class="meta-author-link"><a href="%1$s" title="%2$s">%3$s</a></span>',
						get_author_posts_url( get_the_author_meta( 'ID' ) ),
						sprintf( esc_attr__( 'View posts by this author', 'wpstart' ), get_the_author() ),
						get_the_author()
					)
				);
				
			if ( comments_open() && ! post_password_required() ) :
				echo '<span class="meta-comments-link">';
					comments_popup_link( __( 'Leave a comment', 'wpstart' ), __( '1 Comment', 'wpstart' ), __( '% Comments', 'wpstart' ), 'comments-link' );
				echo '</span>';
			endif;	
		echo '</div>';
	}
}

/* wpstart_single_entry_navigation */
if ( !function_exists( 'wpstart_single_entry_navigation' ) ) {
	function wpstart_single_entry_navigation() {
		?>
		<div class="entry-navigation">
			<div class="previous-entry"><?php previous_post_link('%link', '<span> &larr; </span> %title'); ?></div>
			<div class="next-entry"><?php next_post_link('%link', '%title <span> &rarr; </span>'); ?></div>
		</div>
		<?php
	}
}


?>